# metagentorch


<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

This repo includes the code developed as part of a research project
aiming at using deep learning techniques to classify a wide range of
viruses based on NG reads.

The code is structured into *general code* and *submodules*:

***General code*** is used across the project and can also be reused for
other projects:

1.  `art`: wrapper code to use ART-ILLUMINA read simulator package from
    a jupyter notebook. MUST BE RUN LOCALLY.
2.  `core`: base classes used accross the package
3.  `wandb`: utility classes to open, retrieve, use WandB runs and
    artifacts accross the project

***Submodules*** cover code written for a specific part of the project.
At the moment, the only submodule is `cnn_virus`.

1.  `cnn_virus`: all specific code related to the evaluation and
    improvement of CNN Virus model
    - `architecture`: all code related to evaluated and trained
      architectures
    - `data`: data processing, iterators and parsing functions to handle
      data
    - `utils`: other utility functions

***Note***: This package started as `metagentoools`, using keras 2 and
tensorflow. Now with keras 3, it is possible to user pytorch as a
backend and the package is ported to `metagentorch`. This is the active
package, with `metagentools` currently no longer maintained.

***Disclaimer***: This repository is currently under development and is
offered as-is. Please note that certain functions or modules might raise
errors or become deprecated without prior notice across different
versions. Efforts will be made to clearly indicate in warnings or error
messages how to substitute deprecated code. Support may or may not be
available, depending on when the request for assistance is made.

***Installation***:

- `pip install metagentorch` for the stable version

- `pip install git+https://github.com/vtecftwy/metagentorch.git@main`
  for the latest committed version

***Requirements***:

- python 3.10 or higher is required for this package
- keras 3.9 and pytorch 2.5
- package tested with python 3.10
